@@ -72,6 +72,7 @@ pub fn run(opts: &Dylint) -> Result<()> {
         #[cfg(not(unix))]
         bail!("`--bisect` is supported only on Unix platforms");
 
+        #[cfg(unix)]
         warn(opts, "`--bisect` is experimental");
     }
 
@@ -425,8 +426,8 @@ fn list_lints(
                     let mut command = dylint_internal::driver(toolchain, &driver)?;
                     command
                         .envs(vec![
-                            (env::DYLINT_LIBS.to_owned(), dylint_libs),
-                            (env::DYLINT_LIST.to_owned(), "1".to_owned()),
+                            (env::DYLINT_LIBS, dylint_libs.as_str()),
+                            (env::DYLINT_LIST, "1"),
                         ])
                         .args(vec!["rustc", "-W", "help"])
                         .success()?;
@@ -454,10 +455,11 @@ fn check_or_fix(
         let target_dir_str = target_dir.to_string_lossy();
         let driver = driver_builder::get(opts, toolchain)?;
         let dylint_libs = serde_json::to_string(&paths)?;
+        let description = format!("with toolchain `{}`", toolchain);
         let mut command = if opts.fix {
-            dylint_internal::fix()
+            dylint_internal::fix(&description)
         } else {
-            dylint_internal::check()
+            dylint_internal::check(&description)
         };
         let mut args = vec!["--target-dir", &target_dir_str];
         if let Some(path) = &opts.manifest_path {
@@ -482,15 +484,12 @@ fn check_or_fix(
         let result = command
             .envs(vec![
                 (
-                    env::CLIPPY_DISABLE_DOCS_LINKS.to_owned(),
-                    clippy_disable_docs_links.clone(),
+                    env::CLIPPY_DISABLE_DOCS_LINKS,
+                    clippy_disable_docs_links.as_str(),
                 ),
-                (env::DYLINT_LIBS.to_owned(), dylint_libs),
-                (
-                    env::RUSTC_WORKSPACE_WRAPPER.to_owned(),
-                    driver.to_string_lossy().to_string(),
-                ),
-                (env::RUSTUP_TOOLCHAIN.to_owned(), toolchain.clone()),
+                (env::DYLINT_LIBS, &dylint_libs),
+                (env::RUSTC_WORKSPACE_WRAPPER, &*driver.to_string_lossy()),
+                (env::RUSTUP_TOOLCHAIN, toolchain),
             ])
             .args(args)
             .success();
